@@ -58,9 +58,17 @@ requests <- function(year = 'all', agency = 'all', search = 'all', answer = F) {
 
     # checks if the file has been previously downloaded
     if(any(grepl(paste0('Pedidos_csv_', i), lista.arquivos.locais)) == T) {
-      print(paste0('Os arquivos de ', i,' foram baixados anteriormente.'))
+      print(paste0('Data for the year  ', i,' found locally.'))
     } else{
-      download_lai()
+      if (RCurl::url.exists(links[x]) == F) { # network is down = message (not an error anymore)
+        message("No internet connection or data source broken.")
+        return(NULL)
+      } else { # network is up = proceed to download
+        message(paste0("Downloading ", i," dataset."))
+        download_lai()
+      } # /if - network up or down
+
+
       # list zip files from the year
       lista.arquivos <- list.files(path = dir.temp, pattern = paste0("Arquivos_csv_", i, ".zip"), full.names = TRUE)
       arquivo.pedido <- unzip(zipfile = lista.arquivos, list = T)
@@ -70,13 +78,17 @@ requests <- function(year = 'all', agency = 'all', search = 'all', answer = F) {
     }
 
     # read the files
-    lista.arquivos.locais <- list.files(path = dir.temp, pattern = "*.csv", full.names = TRUE)
-    caminho.arquivo <- stringr::str_subset(lista.arquivos.locais, paste0("Pedidos_csv_",i))
+    lista.arquivos.locais <- list.files(path = dir.temp, pattern = "\\.csv", full.names = TRUE)
+    caminho.arquivo <- stringr::str_subset(lista.arquivos.locais, paste0("_Pedidos_csv_",i))
     var <- readr::read_csv2(file = caminho.arquivo, col_names = FALSE, quote = '\'', show_col_types = FALSE, locale = readr::locale(encoding="UTF-16LE"))
+    if(ncol(var) == 1) { # error message
+      message(paste0("Inconsistent data for the year ", i, "."))
+    } else{
     colnames(var) <- nomes.colunas
     var <- var %>%
       dplyr::select(2,4:13,15,18:21)
     tabela <- rbind(tabela, var)
+    }
     rm(list = 'var') # remove variável para liberar RAM
   }
 
@@ -129,6 +141,6 @@ requests <- function(year = 'all', agency = 'all', search = 'all', answer = F) {
 
   }
 
-  print('Consulta finalizada.')
+  message('Ended query.')
   return(tabela.final)
 }
